@@ -42,7 +42,7 @@ setting.
 
 If there is no function SYM, we try stripping
 `proof-assistant-symbol' and adding \"proof-\" instead to get
-a function name.  This extends proof-set-value to work with
+a function name.  This extends `proof-set-value' to work with
 generic individual settings.
 
 The dynamic action call only happens when values *change*: as an
@@ -102,7 +102,7 @@ be inserted as the user types commands to the prover."
 (defcustom proof-omit-proofs-option nil
   "Set to t to omit complete opaque proofs for speed reasons.
 When t, complete opaque proofs in the asserted region are not
-sent to the proof assistant (and thus not checked). For files
+sent to the proof assistant (and thus not checked).  For files
 with big proofs this can drastically reduce the processing time
 for the asserted region at the cost of not checking the proofs.
 For partial and non-opaque proofs in the asserted region all
@@ -178,7 +178,7 @@ done if this `proof-strict-state-preserving' is turned off (nil)."
 (defcustom proof-strict-read-only 'retract
   "*Whether Proof General is strict about the read-only region in buffers.
 If non-nil, an error is given when an attempt is made to edit the
-read-only region, except for the special value 'retract which means
+read-only region, except for the special value \\+`retract' which means
 undo first.  If nil, Proof General is more relaxed (but may give
 you a reprimand!)."
   :type  '(choice
@@ -232,13 +232,12 @@ and displayed lazily.  See `proof-layout-windows'."
 
 (defcustom proof-three-window-mode-policy 'smart
   "*Window splitting policy for three window mode.
-- If 'vertical then never split horizontally.
-- If 'horizontal then always have scripting buffer on the right
-  and goal and response buffers on the left (one above the
-  other).
-- If 'smart or anything else: 'horizontal when the window
-  is wide enough and 'vertical otherwise.  The width threshold
-  is given by `split-width-threshold'.
+- If \\+`vertical' forces one column mode.
+- If \\+`horizontal' forces 3 column mode
+- If \\+`hybrid' forces 2 columns mode
+- If \\+`smart' or anything else: \\+`horizontal' when the window is wide
+  enough, then hybrid if wide enough and \\+`vertical' otherwise.  The width
+  threshold is given by `split-width-threshold'.
 
   See `proof-layout-windows'."
   :type '(choice
@@ -254,7 +253,7 @@ and displayed lazily.  See `proof-layout-windows'."
 For example, at the end of a proof the goals buffer window will
 be cleared; if this flag is set it will automatically be removed.
 If you want to fix the sizes of your windows you may want to set this
-variable to 'nil' to avoid windows being deleted automatically.
+variable to nil to avoid windows being deleted automatically.
 If you use multiple frames, only the windows in the currently
 selected frame will be automatically deleted."
   :type 'boolean
@@ -263,11 +262,11 @@ selected frame will be automatically deleted."
 (defcustom proof-shell-kill-function-also-kills-associated-buffers t
   "*If non-nil, when `proof-shell-kill-function' is called, clean up buffers.
 For example, `proof-shell-kill-function' is called when buffers
-are retracted when switching between proof script files. It may
-make sense to set this to `nil' when
+are retracted when switching between proof script files.  It may
+make sense to set this to nil when
 `proof-multiple-frames-enable' is set to prevent proof general
 from killing frames that you want to be managed by a window
-manager instead of within emacs."
+manager instead of within Emacs."
   :type 'boolean
   :group 'proof-user-options)
 
@@ -377,14 +376,14 @@ This variable exists to disable the cache in case of problems."
 
 (defcustom proof-follow-mode 'locked
   "*Choice of how point moves with script processing commands.
-One of the symbols: 'locked, 'follow, 'followdown, 'ignore.
+One of the symbols: \\+`locked', \\+`follow', \\+`followdown', \\+`ignore'.
 
-If 'locked, point sticks to the end of the locked region.
-If 'follow, point moves just when needed to display the locked region end.
-If 'followdown, point if necessary to stay in writeable region
-If 'ignore, point is never moved after movement commands or on errors.
+If \\+`locked', point sticks to the end of the locked region.
+If \\+`follow', point moves just when needed to display the locked region end.
+If \\+`followdown', point if necessary to stay in writable region
+If \\+`ignore', point is never moved after movement commands or on errors.
 
-If you choose 'ignore, you can find the end of the locked using
+If you choose \\+`ignore', you can find the end of the locked using
 \\[proof-goto-end-of-locked]"
   :type '(choice
 	  (const :tag "Follow locked region" locked)
@@ -400,9 +399,9 @@ If you choose 'ignore, you can find the end of the locked using
 ;; ancestor file).  And in that case (supposing file being unlocked is
 ;; an ancestor), it seems unlikely that we need to query for saves.
 (defcustom proof-auto-action-when-deactivating-scripting nil
-  "*If 'retract or 'process, do that when deactivating scripting.
+  "*If \\+`retract' or \\+`process', do that when deactivating scripting.
 
-With this option set to 'retract or 'process, when scripting
+With this option set to \\+`retract' or \\+`process', when scripting
 is turned off in a partly processed buffer, the buffer will be
 retracted or processed automatically.
 
@@ -418,7 +417,7 @@ locked (coloured blue); a buffer is completely unprocessed when there
 is no locked region.
 
 For some proof assistants (such as Coq) fully processed buffers make
-no sense.  Setting this option to 'process has then the same effect
+no sense.  Setting this option to \\+`process' has then the same effect
 as leaving it unset (nil).  (This behaviour is controlled by
 `proof-no-fully-processed-buffer'.)"
   :type '(choice
@@ -471,7 +470,7 @@ regions of the script."
 
 (defcustom proof-minibuffer-messages nil
   "*Non-nil causes Proof General to issue minibuffer messages.
-Minibuffer messages are issed when urgent messages are seen
+Minibuffer messages are issued when urgent messages are seen
 from the prover.  You can disable the display of these if they
 are distracting or too frequent."
   :type 'boolean
